@@ -967,32 +967,30 @@ def perez(surface_tilt, surface_azimuth, dhi, dni, dni_extra,
           solar_zenith, solar_azimuth, airmass,
           modelt='allsitescomposite1990'):
     '''
-    Determine diffuse irradiance from the sky on a tilted surface using one of
-    the Perez models.
+    Determine diffuse irradiance from the sky on a tilted surface using
+    one of the Perez models.
 
     Perez models determine the diffuse irradiance from the sky (ground
     reflected irradiance is not included in this algorithm) on a tilted
     surface using the surface tilt angle, surface azimuth angle, diffuse
     horizontal irradiance, direct normal irradiance, extraterrestrial
     irradiance, sun zenith angle, sun azimuth angle, and relative (not
-    pressure-corrected) airmass. Optionally a selector may be used to use
-    any of Perez's model coefficient sets.
+    pressure-corrected) airmass. Optionally a selector may be used to
+    use any of Perez's model coefficient sets.
 
 
     Parameters
     ----------
 
     surface_tilt : float or Series
-        Surface tilt angles in decimal degrees.
-        surface_tilt must be >=0 and <=180. The tilt angle is defined as
-        degrees from horizontal (e.g. surface facing up = 0, surface facing
-        horizon = 90)
+        Surface tilt angles in decimal degrees. surface_tilt must be >=0
+        and <=180. The tilt angle is defined as degrees from horizontal
+        (e.g. surface facing up = 0, surface facing horizon = 90)
 
     surface_azimuth : float or Series
-        Surface azimuth angles in decimal degrees.
-        surface_azimuth must be >=0 and <=360. The Azimuth convention is defined
-        as degrees east of north (e.g. North = 0, South=180 East = 90,
-        West = 270).
+        Surface azimuth angles in decimal degrees. surface_azimuth must
+        be >=0 and <=360. The Azimuth convention is defined as degrees
+        east of north (e.g. North = 0, South=180 East = 90, West = 270).
 
     dhi : float or Series
         Diffuse horizontal irradiance in W/m^2.
@@ -1011,22 +1009,20 @@ def perez(surface_tilt, surface_azimuth, dhi, dni, dni_extra,
         solar_zenith must be >=0 and <=180.
 
     solar_azimuth : float or Series
-        Sun azimuth angles in decimal degrees.
-        solar_azimuth must be >=0 and <=360. The Azimuth convention is defined
-        as degrees east of north (e.g. North = 0, East = 90, West = 270).
+        Sun azimuth angles in decimal degrees. solar_azimuth must be >=0
+        and <=360. The Azimuth convention is defined as degrees east of
+        north (e.g. North = 0, East = 90, West = 270).
 
     airmass : float or Series
-        relative (not pressure-corrected) airmass
-        values. If AM is a DataFrame it must be of the same size as all other
-        DataFrame inputs. AM must be >=0 (careful using the 1/sec(z) model of
-        AM generation)
+        Relative (not pressure-corrected) airmass values. If AM is a
+        DataFrame it must be of the same size as all other DataFrame
+        inputs. AM must be >=0 (careful using the 1/sec(z) model of AM
+        generation)
 
     model : string (optional, default='allsitescomposite1990')
-
-        A string which selects the desired set of Perez
-        coefficients. If model is not provided as an input, the default,
-        '1990' will be used.
-        All possible model selections are:
+        A string which selects the desired set of Perez coefficients. If
+        model is not provided as an input, the default, '1990' will be
+        used. All possible model selections are:
 
         * '1990'
         * 'allsitescomposite1990' (same as '1990')
@@ -1046,44 +1042,42 @@ def perez(surface_tilt, surface_azimuth, dhi, dni, dni_extra,
 
     float or Series
 
-        The diffuse component of the solar radiation  on an
-        arbitrarily tilted surface defined by the Perez model as given in
-        reference [3].
-        SkyDiffuse is the diffuse component ONLY and does not include the
-        ground reflected irradiance or the irradiance due to the beam.
+        The diffuse component of the solar radiation on an arbitrarily
+        tilted surface defined by the Perez model as given in reference
+        [3]. SkyDiffuse is the diffuse component ONLY and does not
+        include the ground reflected irradiance or the irradiance due to
+        the beam.
 
 
     References
     ----------
 
-    [1] Loutzenhiser P.G. et. al. "Empirical validation of models to compute
-    solar irradiance on inclined surfaces for building energy simulation"
-    2007, Solar Energy vol. 81. pp. 254-267
+    [1] Loutzenhiser P.G. et. al. "Empirical validation of models to
+    compute solar irradiance on inclined surfaces for building energy
+    simulation" 2007, Solar Energy vol. 81. pp. 254-267
 
-    [2] Perez, R., Seals, R., Ineichen, P., Stewart, R., Menicucci, D., 1987.
-    A new simplified version of the Perez diffuse irradiance model for tilted
-    surfaces. Solar Energy 39(3), 221-232.
+    [2] Perez, R., Seals, R., Ineichen, P., Stewart, R., Menicucci, D.,
+    1987. A new simplified version of the Perez diffuse irradiance model
+    for tilted surfaces. Solar Energy 39(3), 221-232.
 
-    [3] Perez, R., Ineichen, P., Seals, R., Michalsky, J., Stewart, R., 1990.
-    Modeling daylight availability and irradiance components from direct
-    and global irradiance. Solar Energy 44 (5), 271-289.
+    [3] Perez, R., Ineichen, P., Seals, R., Michalsky, J., Stewart, R.,
+    1990. Modeling daylight availability and irradiance components from
+    direct and global irradiance. Solar Energy 44 (5), 271-289.
 
     [4] Perez, R. et. al 1988. "The Development and Verification of the
     Perez Diffuse Radiation Model". SAND88-7030
     '''
 
-    pvl_logger.debug('diffuse_sky.perez()')
-
     kappa = 1.041  # for solar_zenith in radians
     z = np.radians(solar_zenith)  # convert to radians
 
     # epsilon is the sky's "clearness"
     eps = ((dhi + dni) / dhi + kappa * (z ** 3)) / (1 + kappa * (z ** 3))
 
-    # Perez et al define clearness bins according to the following rules.
-    # 1 = overcast ... 8 = clear
-    # (these names really only make sense for small zenith angles, but...)
-    # these values will eventually be used as indicies for coeffecient look ups
+    # Perez et al define clearness bins according to the following
+    # rules. 1 = overcast ... 8 = clear (these names really only make
+    # sense for small zenith angles, but...) these values will
+    # eventually be used as indicies for coeffecient look ups
     ebin = eps.copy()
     ebin[(eps < 1.065)] = 1
     ebin[(eps >= 1.065) & (eps < 1.23)] = 2
@@ -1100,11 +1094,11 @@ def perez(surface_tilt, surface_azimuth, dhi, dni, dni_extra,
     ebin = ebin.dropna().astype(int)
 
     # This is added because in cases where the sun is below the horizon
-    # (var.solar_zenith > 90) but there is still diffuse horizontal light
-    # (var.DHI>0), it is possible that the airmass (var.AM) could be NaN, which
-    # messes up later calculations. Instead, if the sun is down, and there is
-    # still var.DHI, we set the airmass to the airmass value on the horizon
-    # (approximately 37-38).
+    # (var.solar_zenith > 90) but there is still diffuse horizontal
+    # light (var.DHI>0), it is possible that the airmass (var.AM) could
+    # be NaN, which messes up later calculations. Instead, if the sun is
+    # down, and there is still var.DHI, we set the airmass to the
+    # airmass value on the horizon (approximately 37-38).
     # var.AM(var.solar_zenith >=90 & var.DHI >0) = 37;
 
     # var.DNI_ET[var.DNI_ET==0] = .00000001 #very hacky, fix this
@@ -1112,19 +1106,17 @@ def perez(surface_tilt, surface_azimuth, dhi, dni, dni_extra,
     # delta is the sky's "brightness"
     delta = dhi * airmass / dni_extra
 
-    # keep only valid times
-    delta = delta[ebin.index]
-    z = z[ebin.index]
-
     # The various possible sets of Perez coefficients are contained
     # in a subfunction to clean up the code.
     F1c, F2c = _get_perez_coefficients(modelt)
 
-    F1 = F1c[ebin, 0] + F1c[ebin, 1] * delta + F1c[ebin, 2] * z
+    F1 = (F1c[ebin, 0] + F1c[ebin, 1] * delta[ebin.index] +
+          F1c[ebin, 2] * z[ebin.index])
     F1[F1 < 0] = 0
     F1 = F1.astype(float)
 
-    F2 = F2c[ebin, 0] + F2c[ebin, 1] * delta + F2c[ebin, 2] * z
+    F2 = (F2c[ebin, 0] + F2c[ebin, 1] * delta[ebin.index] +
+          F2c[ebin, 2] * z[ebin.index])
     F2[F2 < 0] = 0
     F2 = F2.astype(float)
 
@@ -1141,8 +1133,9 @@ def perez(surface_tilt, surface_azimuth, dhi, dni, dni_extra,
     term2 = F1 * A[ebin.index] / B[ebin.index]
     term3 = F2 * tools.sind(surface_tilt)
 
-    sky_diffuse = dhi[ebin.index] * (term1 + term2 + term3)
+    sky_diffuse = dhi * (term1 + term2 + term3)
     sky_diffuse[sky_diffuse < 0] = 0
+    sky_diffuse[airmass.isnull()] = 0
 
     return sky_diffuse
 
@@ -1313,12 +1306,12 @@ def _get_perez_coefficients(perezmodelt):
 
 def disc(ghi, zenith, times, pressure=101325):
     '''
-    Estimate Direct Normal Irradiance from Global Horizontal Irradiance 
+    Estimate Direct Normal Irradiance from Global Horizontal Irradiance
     using the DISC model.
 
     The DISC algorithm converts global horizontal irradiance to direct
     normal irradiance through empirical relationships between the global
-    and direct clearness indices. 
+    and direct clearness indices.
 
     Parameters
     ----------
@@ -1327,62 +1320,62 @@ def disc(ghi, zenith, times, pressure=101325):
         Global horizontal irradiance in W/m^2.
 
     solar_zenith : Series
-        True (not refraction - corrected) solar zenith 
-        angles in decimal degrees. 
+        True (not refraction - corrected) solar zenith
+        angles in decimal degrees.
 
     times : DatetimeIndex
 
     pressure : float or Series
         Site pressure in Pascal.
 
-    Returns   
+    Returns
     -------
     DataFrame with the following keys:
-        * ``dni``: The modeled direct normal irradiance 
+        * ``dni``: The modeled direct normal irradiance
           in W/m^2 provided by the
-          Direct Insolation Simulation Code (DISC) model. 
-        * ``kt``: Ratio of global to extraterrestrial 
+          Direct Insolation Simulation Code (DISC) model.
+        * ``kt``: Ratio of global to extraterrestrial
           irradiance on a horizontal plane.
         * ``airmass``: Airmass
 
     References
     ----------
 
-    [1] Maxwell, E. L., "A Quasi-Physical Model for Converting Hourly 
-    Global Horizontal to Direct Normal Insolation", Technical 
-    Report No. SERI/TR-215-3087, Golden, CO: Solar Energy Research 
+    [1] Maxwell, E. L., "A Quasi-Physical Model for Converting Hourly
+    Global Horizontal to Direct Normal Insolation", Technical
+    Report No. SERI/TR-215-3087, Golden, CO: Solar Energy Research
     Institute, 1987.
 
-    [2] J.W. "Fourier series representation of the position of the sun". 
+    [2] J.W. "Fourier series representation of the position of the sun".
     Found at:
     http://www.mail-archive.com/sundial@uni-koeln.de/msg01050.html on
     January 12, 2012
 
-    See Also 
-    -------- 
-    atmosphere.alt2pres 
+    See Also
+    --------
+    atmosphere.alt2pres
     dirint
     '''
 
     pvl_logger.debug('clearsky.disc')
-    
+
     temp = pd.DataFrame(index=times, columns=['A','B','C'], dtype=float)
 
     doy = times.dayofyear
-    
+
     DayAngle = 2. * np.pi*(doy - 1) / 365
-    
+
     re = (1.00011 + 0.034221*np.cos(DayAngle) + 0.00128*np.sin(DayAngle)
           + 0.000719*np.cos(2.*DayAngle) + 7.7e-05*np.sin(2.*DayAngle) )
-          
+
     I0 = re * 1370.
     I0h = I0 * np.cos(np.radians(zenith))
-    
+
     Ztemp = zenith.copy()
     Ztemp[zenith > 87] = np.NaN
-    
+
     AM = 1.0 / ( np.cos(np.radians(Ztemp)) + 0.15*( (93.885 - Ztemp)**(-1.253) ) ) * (pressure / 101325)
-    
+
     Kt = ghi / I0h
     Kt[Kt < 0] = 0
     Kt[Kt > 2] = np.NaN
@@ -1395,10 +1388,10 @@ def disc(ghi, zenith, times, pressure=101325):
     temp.C[Kt <= 0.6] = -0.28 + 0.932*(Kt[Kt <= 0.6]) - 2.048*(Kt[Kt <= 0.6] ** 2)
 
     delKn = temp.A + temp.B * np.exp(temp.C*AM)
-   
+
     Knc = 0.866 - 0.122*(AM) + 0.0121*(AM ** 2) - 0.000653*(AM ** 3) + 1.4e-05*(AM ** 4)
     Kn = Knc - delKn
-    
+
     dni = Kn * I0
 
     dni[zenith > 87] = np.NaN
@@ -1409,14 +1402,14 @@ def disc(ghi, zenith, times, pressure=101325):
     dfout['airmass'] = AM
 
     return dfout
-    
 
-def dirint(ghi, zenith, times, pressure=101325, use_delta_kt_prime=True, 
+
+def dirint(ghi, zenith, times, pressure=101325, use_delta_kt_prime=True,
            temp_dew=None):
     """
-    Determine DNI from GHI using the DIRINT modification 
+    Determine DNI from GHI using the DIRINT modification
     of the DISC model.
-    
+
     Implements the modified DISC model known as "DIRINT" introduced in [1].
     DIRINT predicts direct normal irradiance (DNI) from measured global
     horizontal irradiance (GHI). DIRINT improves upon the DISC model by
@@ -1425,22 +1418,22 @@ def dirint(ghi, zenith, times, pressure=101325, use_delta_kt_prime=True,
     information provided.
 
     Parameters
-    ----------  
+    ----------
     ghi : pd.Series
-        Global horizontal irradiance in W/m^2. 
-    
+        Global horizontal irradiance in W/m^2.
+
     zenith : pd.Series
         True (not refraction-corrected) zenith
         angles in decimal degrees. If Z is a vector it must be of the
         same size as all other vector inputs. Z must be >=0 and <=180.
-    
+
     times : DatetimeIndex
-        
+
     pressure : float or pd.Series
-        The site pressure in Pascal. 
-        Pressure may be measured or an average pressure may be 
+        The site pressure in Pascal.
+        Pressure may be measured or an average pressure may be
         calculated from site altitude.
-    
+
     use_delta_kt_prime : bool
         Indicates if the user would like to
         utilize the time-series nature of the GHI measurements. A value of ``False``
@@ -1450,13 +1443,13 @@ def dirint(ghi, zenith, times, pressure=101325, use_delta_kt_prime=True,
         than 1.5 hours. If none of the input arguments are
         vectors, then time-series improvements are not used (because it's not
         a time-series).
-    
-    temp_dew : None, float, or pd.Series 
-        Surface dew point temperatures, in degrees C. 
+
+    temp_dew : None, float, or pd.Series
+        Surface dew point temperatures, in degrees C.
         Values of temp_dew may be numeric or NaN. Any
         single time period point with a DewPtTemp=NaN does not have dew point
-        improvements applied. If DewPtTemp is not provided, then dew point 
-        improvements are not applied.  
+        improvements applied. If DewPtTemp is not provided, then dew point
+        improvements are not applied.
 
     Returns
     -------
@@ -1467,59 +1460,58 @@ def dirint(ghi, zenith, times, pressure=101325, use_delta_kt_prime=True,
     References
     ----------
     [1] Perez, R., P. Ineichen, E. Maxwell, R. Seals and A. Zelenka, (1992).
-    "Dynamic Global-to-Direct Irradiance Conversion Models".  ASHRAE 
+    "Dynamic Global-to-Direct Irradiance Conversion Models".  ASHRAE
     Transactions-Research Series, pp. 354-369
 
-    [2] Maxwell, E. L., "A Quasi-Physical Model for Converting Hourly 
-    Global Horizontal to Direct Normal Insolation", Technical 
-    Report No. SERI/TR-215-3087, Golden, CO: Solar Energy Research 
+    [2] Maxwell, E. L., "A Quasi-Physical Model for Converting Hourly
+    Global Horizontal to Direct Normal Insolation", Technical
+    Report No. SERI/TR-215-3087, Golden, CO: Solar Energy Research
     Institute, 1987.
 
     DIRINT model requires time series data (ie. one of the inputs must be a
     vector of length >2.
     """
-    
+
     pvl_logger.debug('clearsky.dirint')
-    
+
     disc_out = disc(ghi, zenith, times)
     kt = disc_out['kt']
-    
+
     # Absolute Airmass, per the DISC model
     # Note that we calculate the AM pressure correction slightly differently
     # than Perez. He uses altitude, we use pressure (which we calculate
     # slightly differently)
-    airmass = (1./(tools.cosd(zenith) + 0.15*((93.885-zenith)**(-1.253))) * 
+    airmass = (1./(tools.cosd(zenith) + 0.15*((93.885-zenith)**(-1.253))) *
                pressure/101325)
-    
+
     coeffs = _get_dirint_coeffs()
-    
+
     kt_prime = kt / (1.031 * np.exp(-1.4/(0.9+9.4/airmass)) + 0.1)
     kt_prime[kt_prime > 0.82] = 0.82 # From SRRL code. consider np.NaN
-    kt_prime.fillna(0, inplace=True)
     pvl_logger.debug('kt_prime:\n%s', kt_prime)
-    
-    # wholmgren: 
+
+    # wholmgren:
     # the use_delta_kt_prime statement is a port of the MATLAB code.
     # I am confused by the abs() in the delta_kt_prime calculation.
     # It is not the absolute value of the central difference.
     if use_delta_kt_prime:
         delta_kt_prime = 0.5*( (kt_prime - kt_prime.shift(1)).abs()
                               .add(
-                               (kt_prime - kt_prime.shift(-1)).abs(), 
+                               (kt_prime - kt_prime.shift(-1)).abs(),
                                    fill_value=0))
     else:
         delta_kt_prime = pd.Series(-1, index=times)
-    
+
     if temp_dew is not None:
         w = pd.Series(np.exp(0.07 * temp_dew - 0.075), index=times)
     else:
         w = pd.Series(-1, index=times)
-    
+
     # @wholmgren: the following bin assignments use MATLAB's 1-indexing.
     # Later, we'll subtract 1 to conform to Python's 0-indexing.
-    
+
     # Create kt_prime bins
-    kt_prime_bin = pd.Series(index=times)
+    kt_prime_bin = pd.Series(0, index=times, dtype=np.int64)
     kt_prime_bin[(kt_prime>=0) & (kt_prime<0.24)] = 1
     kt_prime_bin[(kt_prime>=0.24) & (kt_prime<0.4)] = 2
     kt_prime_bin[(kt_prime>=0.4) & (kt_prime<0.56)] = 3
@@ -1527,9 +1519,9 @@ def dirint(ghi, zenith, times, pressure=101325, use_delta_kt_prime=True,
     kt_prime_bin[(kt_prime>=0.7) & (kt_prime<0.8)] = 5
     kt_prime_bin[(kt_prime>=0.8) & (kt_prime<=1)] = 6
     pvl_logger.debug('kt_prime_bin:\n%s', kt_prime_bin)
-    
+
     # Create zenith angle bins
-    zenith_bin = pd.Series(index=times)
+    zenith_bin = pd.Series(0, index=times, dtype=np.int64)
     zenith_bin[(zenith>=0) & (zenith<25)] = 1
     zenith_bin[(zenith>=25) & (zenith<40)] = 2
     zenith_bin[(zenith>=40) & (zenith<55)] = 3
@@ -1537,9 +1529,9 @@ def dirint(ghi, zenith, times, pressure=101325, use_delta_kt_prime=True,
     zenith_bin[(zenith>=70) & (zenith<80)] = 5
     zenith_bin[(zenith>=80)] = 6
     pvl_logger.debug('zenith_bin:\n%s', zenith_bin)
-    
+
     # Create the bins for w based on dew point temperature
-    w_bin = pd.Series(index=times)
+    w_bin = pd.Series(0, index=times, dtype=np.int64)
     w_bin[(w>=0) & (w<1)] = 1
     w_bin[(w>=1) & (w<2)] = 2
     w_bin[(w>=2) & (w<3)] = 3
@@ -1548,7 +1540,7 @@ def dirint(ghi, zenith, times, pressure=101325, use_delta_kt_prime=True,
     pvl_logger.debug('w_bin:\n%s', w_bin)
 
     # Create delta_kt_prime binning.
-    delta_kt_prime_bin = pd.Series(index=times)
+    delta_kt_prime_bin = pd.Series(0, index=times, dtype=np.int64)
     delta_kt_prime_bin[(delta_kt_prime>=0) & (delta_kt_prime<0.015)] = 1
     delta_kt_prime_bin[(delta_kt_prime>=0.015) & (delta_kt_prime<0.035)] = 2
     delta_kt_prime_bin[(delta_kt_prime>=0.035) & (delta_kt_prime<0.07)] = 3
@@ -1557,11 +1549,15 @@ def dirint(ghi, zenith, times, pressure=101325, use_delta_kt_prime=True,
     delta_kt_prime_bin[(delta_kt_prime>=0.3) & (delta_kt_prime<=1)] = 6
     delta_kt_prime_bin[delta_kt_prime == -1] = 7
     pvl_logger.debug('delta_kt_prime_bin:\n%s', delta_kt_prime_bin)
-    
+
     # subtract 1 to account for difference between MATLAB-style bin
     # assignment and Python-style array lookup.
     dirint_coeffs = coeffs[kt_prime_bin-1, zenith_bin-1,
                            delta_kt_prime_bin-1, w_bin-1]
+    # convert unassigned bins to nan
+    # use where to avoid boolean indexing deprecation
+    dirint_coeffs[np.where((kt_prime_bin == 0) | (zenith_bin == 0) |
+                           (w_bin == 0) | (delta_kt_prime_bin == 0))] = np.nan
 
     dni = disc_out['dni'] * dirint_coeffs
 
@@ -1573,19 +1569,19 @@ def dirint(ghi, zenith, times, pressure=101325, use_delta_kt_prime=True,
 def _get_dirint_coeffs():
     """
     A place to stash the dirint coefficients.
-    
+
     Returns
     -------
     np.array with shape ``(6, 6, 7, 5)``.
     Ordering is ``[kt_prime_bin, zenith_bin, delta_kt_prime_bin, w_bin]``
     """
 
-    # To allow for maximum copy/paste from the MATLAB 1-indexed code, 
+    # To allow for maximum copy/paste from the MATLAB 1-indexed code,
     # we create and assign values to an oversized array.
     # Then, we return the [1:, 1:, :, :] slice.
-    
+
     coeffs = np.zeros((7,7,7,5))
-    
+
     coeffs[1,1,:,:] = [
         [0.385230, 0.385230, 0.385230, 0.462880, 0.317440],
         [0.338390, 0.338390, 0.221270, 0.316730, 0.503650],
@@ -1909,6 +1905,94 @@ def _get_dirint_coeffs():
         [0.570000, 0.550000, 0.598800, 0.400000, 0.560150],
         [0.475230, 0.500000, 0.518640, 0.339970, 0.520230],
         [0.743440, 0.592190, 0.603060, 0.316930, 0.794390 ]]
-        
+
     return coeffs[1:,1:,:,:]
 
+
+def erbs(ghi, zenith, doy):
+    r"""
+    Estimate DNI and DHI from GHI using the Erbs model.
+
+    The Erbs model [1]_ estimates the diffuse fraction DF from global
+    horizontal irradiance through an empirical relationship between DF
+    and the ratio of GHI to extraterrestrial irradiance, Kt. The
+    function uses the diffuse fraction to compute DHI as
+
+    .. math::
+
+        DHI = DF \times GHI
+
+    DNI is then estimated as
+
+    .. math::
+
+        DNI = (GHI - DHI)/\cos(Z)
+
+    where Z is the zenith angle.
+
+    Parameters
+    ----------
+    ghi: scalar, array or Series
+        Global horizontal irradiance in W/m^2.
+    zenith: scalar, array or Series
+        True (not refraction-corrected) zenith angles in decimal degrees.
+    doy: scalar, array or DatetimeIndex
+        The day of the year.
+
+    Returns
+    -------
+    data : DataFrame
+        The DataFrame will have the following columns:
+
+            * ``dni``: the modeled direct normal irradiance in W/m^2.
+            * ``dhi``: the modeled diffuse horizontal irradiance in W/m^2.
+            * ``kt``: Ratio of global to extraterrestrial irradiance
+              on a horizontal plane.
+
+    References
+    ----------
+    .. [1] D. G. Erbs, S. A. Klein and J. A. Duffie, Estimation of the
+       diffuse radiation fraction for hourly, daily and monthly-average
+       global radiation, Solar Energy 28(4), pp 293-302, 1982. Eq. 1
+
+    See also
+    --------
+    dirint
+    disc
+    """
+
+    # enables all scalar input
+    ghi = pd.Series(ghi)
+    zenith = pd.Series(zenith)
+
+    dni_extra = extraradiation(doy)
+
+    # This Z needs to be the true Zenith angle, not apparent,
+    # to get extraterrestrial horizontal radiation)
+    i0_h = dni_extra * tools.cosd(zenith)
+
+    kt = ghi / i0_h
+    kt[kt < 0] = 0
+
+    # For Kt <= 0.22, set the diffuse fraction
+    df = 1 - 0.09*kt
+
+    # For Kt > 0.22 and Kt <= 0.8, set the diffuse fraction
+    mask = (kt > 0.22) & (kt <= 0.8)
+    df[mask] = (
+        0.9511 - 0.1604*kt[mask] + 4.388*kt[mask]**2 - 16.638*kt[mask]**3 +
+        12.336*kt[mask]**4)
+
+    # For Kt > 0.8, set the diffuse fraction
+    df[kt > 0.8] = 0.165
+
+    dhi = df * ghi
+
+    dni = (ghi - dhi) / tools.cosd(zenith)
+
+    data = pd.DataFrame()
+    data['dni'] = dni
+    data['dhi'] = dhi
+    data['kt'] = kt
+
+    return data
