@@ -35,6 +35,15 @@ class PVSystem(object):
     See the :py:class:`LocalizedPVSystem` class for an object model that
     describes an installed PV system.
 
+    The class supports basic system topologies consisting of:
+
+        * `N` total modules arranged in series
+          (`modules_per_string=N`, `strings_per_inverter=1`).
+        * `M` total modules arranged in parallel
+          (`modules_per_string=1`, `strings_per_inverter=M`).
+        * `NxM` total modules arranged in `M` strings of `N` modules each
+          (`modules_per_string=N`, `strings_per_inverter=M`).
+
     The class is complementary to the module-level functions.
 
     The attributes should generally be things that don't change about
@@ -69,6 +78,12 @@ class PVSystem(object):
     module_parameters : None, dict or Series
         Module parameters as defined by the SAPM, CEC, or other.
 
+    modules_per_string: int or float
+        See system topology discussion above.
+
+    strings_per_inverter: int or float
+        See system topology discussion above.
+
     inverter : None, string
         The model name of the inverters.
         May be used to look up the inverter_parameters dictionary
@@ -95,7 +110,7 @@ class PVSystem(object):
                  surface_tilt=0, surface_azimuth=180,
                  albedo=None, surface_type=None,
                  module=None, module_parameters=None,
-                 series_modules=None, parallel_modules=None,
+                 modules_per_string=1, strings_per_inverter=1,
                  inverter=None, inverter_parameters=None,
                  racking_model='open_rack_cell_glassback',
                  **kwargs):
@@ -114,8 +129,8 @@ class PVSystem(object):
         self.module = module
         self.module_parameters = module_parameters
 
-        self.series_modules = series_modules
-        self.parallel_modules = parallel_modules
+        self.modules_per_string = modules_per_string
+        self.strings_per_inverter = strings_per_inverter
 
         self.inverter = inverter
         self.inverter_parameters = inverter_parameters
@@ -125,6 +140,12 @@ class PVSystem(object):
         # needed for tying together Location and PVSystem in LocalizedPVSystem
         super(PVSystem, self).__init__(**kwargs)
 
+    def __repr__(self):
+        return ('PVSystem with tilt:' + str(self.surface_tilt) +
+                ' and azimuth: ' + str(self.surface_azimuth) +
+                ' with Module: ' + str(self.module) +
+                ' and Inverter: ' + str(self.inverter))
+
     def get_aoi(self, solar_zenith, solar_azimuth):
         """Get the angle of incidence on the system.
 
@@ -363,6 +384,28 @@ class PVSystem(object):
         """
         return snlinverter(self.inverter_parameters, v_dc, p_dc)
 
+    def scale_voltage_current_power(self, data):
+        """
+        Scales the voltage, current, and power of the DataFrames
+        returned by :py:func:`singlediode` and :py:func:`sapm`
+        by `self.modules_per_string` and `self.strings_per_inverter`.
+
+        Parameters
+        ----------
+        data: DataFrame
+            Must contain columns `'v_mp', 'v_oc', 'i_mp' ,'i_x', 'i_xx',
+            'i_sc', 'p_mp'`.
+
+        Returns
+        -------
+        scaled_data: DataFrame
+            A scaled copy of the input data.
+        """
+
+        return scale_voltage_current_power(data,
+                                           voltage=self.modules_per_string,
+                                           current=self.strings_per_inverter)
+
     def localize(self, location=None, latitude=None, longitude=None,
                  **kwargs):
         """Creates a LocalizedPVSystem object using this object
@@ -417,9 +460,17 @@ class LocalizedPVSystem(PVSystem, Location):
 
         super(LocalizedPVSystem, self).__init__(**new_kwargs)
 
+    def __repr__(self):
+        return ('LocalizedPVSystem with tilt:' + str(self.surface_tilt) +
+                ' and azimuth: ' + str(self.surface_azimuth) +
+                ' with Module: ' + str(self.module) +
+                ' and Inverter: ' + str(self.inverter) +
+                ' at Latitude: ' + str(self.latitude) +
+                ' and Longitude: ' + str(self.longitude))
 
-def systemdef(meta, surface_tilt, surface_azimuth, albedo, series_modules,
-              parallel_modules):
+
+def systemdef(meta, surface_tilt, surface_azimuth, albedo, modules_per_string,
+              strings_per_inverter):
     '''
     Generates a dict of system parameters used throughout a simulation.
 
@@ -457,10 +508,10 @@ def systemdef(meta, surface_tilt, surface_azimuth, albedo, series_modules,
         (land), may increase over snow, ice, etc. May also be known as
         the reflection coefficient. Must be >=0 and <=1.
 
-    series_modules : int
+    modules_per_string : int
         Number of modules connected in series in a string.
 
-    parallel_modules : int
+    strings_per_inverter : int
         Number of strings connected in parallel.
 
     Returns
@@ -472,8 +523,8 @@ def systemdef(meta, surface_tilt, surface_azimuth, albedo, series_modules,
             * 'surface_tilt'
             * 'surface_azimuth'
             * 'albedo'
-            * 'series_modules'
-            * 'parallel_modules'
+            * 'modules_per_string'
+            * 'strings_per_inverter'
             * 'latitude'
             * 'longitude'
             * 'tz'
@@ -494,8 +545,8 @@ def systemdef(meta, surface_tilt, surface_azimuth, albedo, series_modules,
     system = {'surface_tilt': surface_tilt,
               'surface_azimuth': surface_azimuth,
               'albedo': albedo,
-              'series_modules': series_modules,
-              'parallel_modules': parallel_modules,
+              'modules_per_string': modules_per_string,
+              'strings_per_inverter': strings_per_inverter,
               'latitude': meta['latitude'],
               'longitude': meta['longitude'],
               'tz': meta['TZ'],
@@ -1272,8 +1323,8 @@ def singlediode(module, photocurrent, saturation_current,
 
     Parameters
     ----------
-    module : DataFrame
-        A DataFrame defining the SAPM performance parameters.
+    module : dict or Series
+        A dict-like object defining the SAPM performance parameters.
 
     photocurrent : float or Series
         Light-generated current (photocurrent) in amperes under desired
@@ -1344,15 +1395,16 @@ def singlediode(module, photocurrent, saturation_current,
     i_sc = i_from_v(resistance_shunt, resistance_series, nNsVth, 0.01,
                     saturation_current, photocurrent)
 
+    # Find open circuit voltage using Lambert W
+    v_oc = v_from_i(resistance_shunt, resistance_series, nNsVth, 0.0,
+                    saturation_current, photocurrent)
+
     params = {'r_sh': resistance_shunt,
               'r_s': resistance_series,
               'nNsVth': nNsVth,
               'i_0': saturation_current,
               'i_l': photocurrent}
 
-    __, v_oc = _golden_sect_DataFrame(params, 0, module['V_oc_ref']*1.6,
-                                      _v_oc_optfcn)
-
     p_mp, v_mp = _golden_sect_DataFrame(params, 0, module['V_oc_ref']*1.14,
                                         _pwr_optfcn)
 
@@ -1483,13 +1535,70 @@ def _pwr_optfcn(df, loc):
     return I*df[loc]
 
 
-def _v_oc_optfcn(df, loc):
+def v_from_i(resistance_shunt, resistance_series, nNsVth, current,
+             saturation_current, photocurrent):
     '''
-    Function to find the open circuit voltage from ``i_from_v``.
+    Calculates voltage from current per Eq 3 Jain and Kapoor 2004 [1].
+
+    Parameters
+    ----------
+    resistance_shunt : float or Series
+        Shunt resistance in ohms under desired IV curve conditions.
+        Often abbreviated ``Rsh``.
+
+    resistance_series : float or Series
+        Series resistance in ohms under desired IV curve conditions.
+        Often abbreviated ``Rs``.
+
+    nNsVth : float or Series
+        The product of three components. 1) The usual diode ideal factor
+        (n), 2) the number of cells in series (Ns), and 3) the cell
+        thermal voltage under the desired IV curve conditions (Vth). The
+        thermal voltage of the cell (in volts) may be calculated as
+        ``k*temp_cell/q``, where k is Boltzmann's constant (J/K),
+        temp_cell is the temperature of the p-n junction in Kelvin, and
+        q is the charge of an electron (coulombs).
+
+    current : float or Series
+        The current in amperes under desired IV curve conditions.
+
+    saturation_current : float or Series
+        Diode saturation current in amperes under desired IV curve
+        conditions. Often abbreviated ``I_0``.
+
+    photocurrent : float or Series
+        Light-generated current (photocurrent) in amperes under desired
+        IV curve conditions. Often abbreviated ``I_L``.
+
+    Returns
+    -------
+    current : np.array
+
+    References
+    ----------
+    [1] A. Jain, A. Kapoor, "Exact analytical solutions of the
+    parameters of real solar cells using Lambert W-function", Solar
+    Energy Materials and Solar Cells, 81 (2004) 269-277.
     '''
-    I = -abs(i_from_v(df['r_sh'], df['r_s'], df['nNsVth'],
-                      df[loc], df['i_0'], df['i_l']))
-    return I
+    try:
+        from scipy.special import lambertw
+    except ImportError:
+        raise ImportError('This function requires scipy')
+
+    Rsh = resistance_shunt
+    Rs = resistance_series
+    I0 = saturation_current
+    IL = photocurrent
+    I = current
+
+    argW = I0 * Rsh / nNsVth * np.exp(Rsh *(-I + IL + I0) / nNsVth)
+    lambertwterm = lambertw(argW)
+
+    # Eqn. 3 in Jain and Kapoor, 2004
+
+    V = -I*(Rs + Rsh) + IL*Rsh - nNsVth*lambertwterm + I0*Rsh
+
+    return V.real
 
 
 def i_from_v(resistance_shunt, resistance_series, nNsVth, voltage,
@@ -1574,8 +1683,8 @@ def snlinverter(inverter, v_dc, p_dc):
 
     Parameters
     ----------
-    inverter : DataFrame
-        A DataFrame defining the inverter to be used, giving the
+    inverter : dict or Series
+        A dict-like object defining the inverter to be used, giving the
         inverter performance parameters according to the Sandia
         Grid-Connected Photovoltaic Inverter Model (SAND 2007-5036) [1].
         A set of inverter performance parameters are provided with
@@ -1668,3 +1777,37 @@ def snlinverter(inverter, v_dc, p_dc):
         ac_power = ac_power.ix[0]
 
     return ac_power
+
+
+def scale_voltage_current_power(data, voltage=1, current=1):
+    """
+    Scales the voltage, current, and power of the DataFrames
+    returned by :py:func:`singlediode` and :py:func:`sapm`.
+
+    Parameters
+    ----------
+    data: DataFrame
+        Must contain columns `'v_mp', 'v_oc', 'i_mp' ,'i_x', 'i_xx',
+        'i_sc', 'p_mp'`.
+    voltage: numeric
+        The amount by which to multiply the voltages.
+    current: numeric
+        The amount by which to multiply the currents.
+
+    Returns
+    -------
+    scaled_data: DataFrame
+        A scaled copy of the input data.
+        `'p_mp'` is scaled by `voltage * current`.
+    """
+
+    # as written, only works with a DataFrame
+    # could make it work with a dict, but it would be more verbose
+    data = data.copy()
+    voltages = ['v_mp', 'v_oc']
+    currents = ['i_mp', 'i_x', 'i_xx', 'i_sc']
+    data[voltages] *= voltage
+    data[currents] *= current
+    data['p_mp'] *= voltage * current
+
+    return data
