@@ -239,7 +239,7 @@ def _spa_python_import(how):
 
 def spa_python(time, latitude, longitude,
                altitude=0, pressure=101325, temperature=12, delta_t=None,
-               atmos_refract=None, how='numpy', numthreads=4):
+               atmos_refract=None, how='numpy', numthreads=4, **kwargs):
     """
     Calculate the solar position using a python implementation of the
     NREL SPA algorithm described in [1].
@@ -398,11 +398,11 @@ def get_sun_rise_set_transit(time, latitude, longitude, how='numpy',
         unixtime, lat, lon, delta_t, numthreads)
 
     # arrays are in seconds since epoch format, need to conver to timestamps
-    transit = pd.to_datetime(transit, unit='s', utc=True).tz_convert(
+    transit = pd.to_datetime(transit*1e9, unit='ns', utc=True).tz_convert(
         time.tz).tolist()
-    sunrise = pd.to_datetime(sunrise, unit='s', utc=True).tz_convert(
+    sunrise = pd.to_datetime(sunrise*1e9, unit='ns', utc=True).tz_convert(
         time.tz).tolist()
-    sunset = pd.to_datetime(sunset, unit='s', utc=True).tz_convert(
+    sunset = pd.to_datetime(sunset*1e9, unit='ns', utc=True).tz_convert(
         time.tz).tolist()
 
     result = pd.DataFrame({'transit': transit,
