@@ -29,7 +29,12 @@ class SingleAxisTracker(PVSystem):
         self.gcr = gcr
         
         super(SingleAxisTracker, self).__init__(**kwargs)
-
+        
+        
+    def __repr__(self):
+        return ('SingleAxisTracker with max_angle: ' +
+                str(self.max_angle))
+        
 
     def singleaxis(self, apparent_zenith, apparent_azimuth):
         tracking_data = singleaxis(apparent_zenith, apparent_azimuth,
@@ -158,6 +163,15 @@ class LocalizedSingleAxisTracker(SingleAxisTracker, Location):
                           list(kwargs.items()))
 
         super(LocalizedSingleAxisTracker, self).__init__(**new_kwargs)
+        
+        
+    def __repr__(self):
+        return ('Localized' +
+                super(LocalizedSingleAxisTracker, self).__repr__()
+                + ' at Location: ' + 
+                ('{}: latitude={}, longitude={}, tz={}, altitude={}'
+                .format(self.name, self.latitude, self.longitude, 
+                        self.tz, self.altitude)))
 
 
 def singleaxis(apparent_zenith, apparent_azimuth, 
